@@ -346,5 +346,8 @@ def main(trainset_dir, testset_dir):
             test_data = pd.read_hdf(testset_dir+test_set)
             pred_class = test(model, test_data, train_dataset_list,
                             metrics_list, labels_list)
+        with open('result.txt', 'w') as result_file:
+            for pred_class_indice in range(len(pred_class)):
+                result_file.write(str(test_data.index[pred_class_indice])+'\t'+pred_class[pred_class_indice]+'\n')
 
     torch.save(model.state_dict(), 'pre_trained/model/new_model.pth')
